@@ -46,7 +46,6 @@ setValidity("brob", .Brob.valid)
   }
 }
 
-
 setAs("brob", "numeric", function(from){
   out <- exp(from@x)
   out[!from@positive] <- -out[!from@positive]
@@ -61,7 +60,6 @@ setAs("brob", "complex", function(from){
 
 setMethod("as.complex",signature(x="brob"),function(x){as(x,"complex")})
 
-
 ".Brob.print" <- function(x, digits=5){
      noquote( paste(c("-","+")[1+x@positive],"exp(",signif(x@x,digits),")",sep=""))
    }
@@ -74,7 +72,6 @@ setMethod("as.complex",signature(x="brob"),function(x){as(x,"complex")})
 
 setMethod("show", "brob", function(object){print.brob(object)})
 
-
 setGeneric("getX",function(x){standardGeneric("getX")})
 setGeneric("getP",function(x){standardGeneric("getP")})
 setMethod("getX","brob",function(x){x@x})
@@ -127,7 +124,9 @@ setMethod(".cPair", c("ANY", "ANY"),   function(x,y){c(x,y)})
   brob(c(x@x,y@x),c(x@positive,y@positive))
 }
 
-setGeneric("log",group="Math")
+if(!isGeneric("log")){
+  setGeneric("log",group="Math")
+}
 
 setMethod("sqrt","brob", function(x){
  brob(ifelse(x@positive,x@x/2, NaN),TRUE)
@@ -286,7 +285,7 @@ setMethod("Logic",signature(e1="swift",e2="ANY"), .Brob.logic)
 setMethod("Logic",signature(e1="ANY",e2="swift"), .Brob.logic)
 setMethod("Logic",signature(e1="swift",e2="swift"), .Brob.logic)
 
-
+if(!isGeneric("max")){
 setGeneric("max", function(x, ..., na.rm = FALSE)
 	{
 		standardGeneric("max")
@@ -296,7 +295,9 @@ setGeneric("max", function(x, ..., na.rm = FALSE)
 		base::max(x, ..., na.rm = na.rm)
 	},
 	group = "Summary")
+}
 
+if(!isGeneric("min")){
 setGeneric("min", function(x, ..., na.rm = FALSE)
 	{
 		standardGeneric("min")
@@ -306,7 +307,9 @@ setGeneric("min", function(x, ..., na.rm = FALSE)
 		base::min(x, ..., na.rm = na.rm)
 	},
 	group = "Summary")
+}
 
+if(!isGeneric("range")){
 setGeneric("range", function(x, ..., na.rm = FALSE)
 	{
 		standardGeneric("range")
@@ -316,7 +319,9 @@ setGeneric("range", function(x, ..., na.rm = FALSE)
 		base::range(x, ..., na.rm = na.rm)
 	},
 	group = "Summary")
+}
 
+if(!isGeneric("prod")){
 setGeneric("prod", function(x, ..., na.rm = FALSE)
 	{
 		standardGeneric("prod")
@@ -326,7 +331,9 @@ setGeneric("prod", function(x, ..., na.rm = FALSE)
 		base::prod(x, ..., na.rm = na.rm)
 	},
 	group = "Summary")
+}
 
+if(!isGeneric("sum")){
 setGeneric("sum", function(x, ..., na.rm = FALSE)
 	{
 		standardGeneric("sum")
@@ -336,6 +343,7 @@ setGeneric("sum", function(x, ..., na.rm = FALSE)
 		base::sum(x, ..., na.rm = na.rm)
 	},
 	group = "Summary")
+}
 
 ".Brob.max" <- function(x, ..., na.rm=FALSE){
   p <- x@positive
